@@ -10,6 +10,7 @@ from werkzeug.serving import run_simple
 from pfunk.client import FaunaClient, q
 
 from pfunk.contrib.auth.collections import Group, PermissionGroup
+from pfunk.exceptions import DocNotFound
 from pfunk.template import wsgi_template, project_template, collections_templates, key_template
 from pfunk.utils.deploy import Deploy
 
@@ -231,7 +232,10 @@ def create_admin_user(stage_name: str, group_slug: str, last_name: str, first_na
     )
 
     if group_slug:
-        group = Group.get_by('unique_Group_slug', group_slug)
+        try:
+            group = Group.get_by('unique_Group_slug', group_slug)
+        except DocNotFound:
+            group = Group.create(name=group_slug, slug=group_slug)
         if not project_path:
             project_path = f'{config.get("name")}.project.project'
         sys.path.insert(0, os.getcwd())
